##
##  perl-db.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   versions of individual parts
%define       V_perl           5.22
%define       V_berkeleydb     0.65
%define       V_bdb            1.92
%define       V_db_file        1.858
%define       V_db_file_lock   0.05

#   package information
Name:         perl-db
Summary:      Perl Modules for use with Berkeley-DB
URL:          http://www.cpan.org/
Vendor:       Perl Community
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Perl
License:      GPL/Artistic
Version:      %{V_perl}
Release:      20220514

#   package options
%option       with_pthreads  no

#   list of sources
Source0:      http://www.cpan.org/authors/id/P/PM/PMQS/BerkeleyDB-%{V_berkeleydb}.tar.gz
Source1:      http://www.cpan.org/authors/id/M/ML/MLEHMANN/BDB-%{V_bdb}.tar.gz
Source2:      http://www.cpan.org/authors/id/P/PM/PMQS/DB_File-%{V_db_file}.tar.gz
Source3:      http://www.cpan.org/authors/id/D/DH/DHARRIS/DB_File-Lock-%{V_db_file_lock}.tar.gz
Patch0:       perl-db.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl >= %{V_perl}, perl-openpkg >= %{V_perl}-20040126
PreReq:       OpenPKG, openpkg >= 20160101, perl >= %{V_perl}
BuildPreReq:  db >= 4.1.24
PreReq:       db >= 4.1.24
%if "%{with_pthreads}" == "yes"
BuildPreReq:  db::with_pthreads = yes
PreReq:       db::with_pthreads = yes
%endif

%description
    Various modules for using the Berkeley-DB library from within Perl:
    - BerkeleyDB (%{V_berkeleydb})
    - BDB (%{V_bdb})
    - DB_File (%{V_db_file})
    - DB_File::Lock (%{V_db_file_lock})

%track
    prog perl-db:BerkeleyDB = {
        version   = %{V_berkeleydb}
        url       = http://www.cpan.org/authors/id/P/PM/PMQS/
        regex     = BerkeleyDB-(__VER__)\.tar\.gz
    }
    prog perl-db:BDB = {
        version   = %{V_bdb}
        url       = http://www.cpan.org/authors/id/M/ML/MLEHMANN/
        regex     = BDB-(__VER__)\.tar\.gz
    }
    prog perl-db:DB_File = {
        version   = %{V_db_file}
        url       = http://www.cpan.org/authors/id/P/PM/PMQS/
        regex     = DB_File-(__VER__)\.tar\.gz
    }
    prog perl-db:DB_File-Lock = {
        version   = %{V_db_file_lock}
        url       = http://www.cpan.org/authors/id/D/DH/DHARRIS/
        regex     = DB_File-Lock-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %setup -q -T -D -a 2
    %setup -q -T -D -a 3
    %patch -p0

%build

%install
    %{l_prefix}/bin/perl-openpkg prepare

    #   build BerkeleyDB
    ( cd BerkeleyDB-%{V_berkeleydb}
      ( echo "INCLUDE = %{l_prefix}/include"
        echo "LIB = %{l_prefix}/lib"
      ) >config.in
    ) || exit $?
    %{l_prefix}/bin/perl-openpkg -d BerkeleyDB-%{V_berkeleydb} configure build install

    #   build BDB
%if "%{with_pthreads}" == "yes"
    %{l_shtool} subst \
        -e 's;$INC = "";$INC = "%{l_cppflags} -pthread";' \
        -e 's;-lpthread -ldb;%{l_ldflags} -pthread -ldb;' \
        BDB-%{V_bdb}/Makefile.PL
    %{l_prefix}/bin/perl-openpkg -d BDB-%{V_bdb} configure build install
%endif

    #   build DB_File
    ( cd DB_File-%{V_db_file}
      ( echo "PREFIX = size_t"
        echo "HASH = u_int32_t"
        echo "INCLUDE = %{l_prefix}/include"
        echo "LIB = %{l_prefix}/lib"
      ) >config.in
      %{l_shtool} subst -e "s;INSTALLDIRS => .perl.,;;" Makefile.PL
    ) || exit $?
    %{l_prefix}/bin/perl-openpkg -d DB_File-%{V_db_file} configure build install

    %{l_prefix}/bin/perl-openpkg -d %{SOURCE3}  configure build install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

